import os
import pathlib
from configparser import ConfigParser


class Configuration:

    LOCAL_CFG_FNAME = os.path.join(pathlib.Path().absolute(), 'default.ini')

    def __init__(self, app_name=None):
        self._cfg_local_parser = None
        self._cfg_home_dir_parser = None
        self._app_name = app_name

    def __getitem__(self, key: str) -> str:
        if os.getenv(key) and os.getenv(key):
            return os.getenv(key)
        elif self._local_configuration_file() and self._local_configuration_file()['DEFAULT'].get(key, None):
            return self._local_configuration_file()['DEFAULT'][key]
        elif self._home_dir_configuration_file() and self._home_dir_configuration_file()['DEFAULT'].get(key, None):
            return self._home_dir_configuration_file()['DEFAULT'][key]

    def _local_configuration_file(self) -> ConfigParser:
        if self._cfg_local_parser:
            return self._cfg_local_parser

        self._cfg_local_parser = _build_cfg_parser(Configuration.LOCAL_CFG_FNAME)
        return self._cfg_local_parser

    def _home_dir_configuration_file(self) -> ConfigParser:
        if self._cfg_home_dir_parser:
            return self._cfg_home_dir_parser

        if not self._app_name:
            return None

        cfg_file_name = os.path.join(pathlib.Path.home(), '.' + self._app_name, 'default.ini')
        self._cfg_home_dir_parser = _build_cfg_parser(cfg_file_name)
        return self._cfg_home_dir_parser


def _build_cfg_parser(file_name: str):
    cfg_parser = ConfigParser()
    cfg_parser.read(file_name)
    return cfg_parser









import os
from setuptools import setup

from just_config import version


# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='just-config',
    version=version.VERSION,
    author='Alexander Pushkarev',
    author_email='alexspush@gmail.com',
    description='Minimalistic library to handle configuration for the application',
    license='MIT',
    url='http://packages.python.org/just_config',
    packages=['just_config'],
    long_description=read('README.md'),
    long_description_content_type='text/markdown'
)
